//-*-c++-*-
/**
 Author: David Auber
 Email : auber@labri.fr
 Last modification : 20/08/2001
 This program is free software; you can redistribute it and/or modify  *
 it under the terms of the GNU General Public License as published by  
 the Free Software Foundation; either version 2 of the License, or     
 (at your option) any later version.
*/


#ifndef TULIP_INT_H
#define TULIP_INT_H

#include "Types.h"
#include "Property.h"
class PropertyContext;
class IntProxy;

/** \addtogroup plugins */ 
/*@{*/

/// Interface for int plug-ins
class Int:public Property<IntType , IntType>
{ 
  ///
  friend class IntProxy;
public:
  /** This int proxy is the one associated to the plug-ins,
      The data should be store in it*/
  IntProxy *intProxy;
protected:
  ///
  Int (const PropertyContext  &context);
  ///
  virtual ~Int(){}
};
/*@}*/
#endif









